@@ -1,3 +1,6 @@
+# nopycln: file
 from pyinspect.exceptions import install_traceback, print_exception
-from pyinspect.utils import print_function
+from pyinspect.utils import showme
 from pyinspect.find import search
+
+from rich import inspect as rinspect
